==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/cdn/kotlin/inputs/SecurityPolicyWebApplicationFirewallAssociationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.cdn.kotlin.inputs

import com.pulumi.azurenative.cdn.inputs.SecurityPolicyWebApplicationFirewallAssociationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * settings for security policy patterns to match
 * @property domains List of domains.
 * @property patternsToMatch List of paths
 */
public data class SecurityPolicyWebApplicationFirewallAssociationArgs(
    public val domains: Output<List<ActivatedResourceReferenceArgs>>? = null,
    public val patternsToMatch: Output<List<String>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.cdn.inputs.SecurityPolicyWebApplicationFirewallAssociationArgs> {
    override fun toJava():
        com.pulumi.azurenative.cdn.inputs.SecurityPolicyWebApplicationFirewallAssociationArgs =
        com.pulumi.azurenative.cdn.inputs.SecurityPolicyWebApplicationFirewallAssociationArgs.builder()
            .domains(
                domains?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .patternsToMatch(patternsToMatch?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [SecurityPolicyWebApplicationFirewallAssociationArgs].
 */
@PulumiTagMarker
public class SecurityPolicyWebApplicationFirewallAssociationArgsBuilder internal constructor() {
    private var domains: Output<List<ActivatedResourceReferenceArgs>>? = null

    private var patternsToMatch: Output<List<String>>? = null

    /**
     * @param value List of domains.
     */
    @JvmName("ebembirvwchsgmwu")
    public suspend fun domains(`value`: Output<List<ActivatedResourceReferenceArgs>>) {
        this.domains = value
    }

    @JvmName("fjrkwtvgagnyolbc")
    public suspend fun domains(vararg values: Output<ActivatedResourceReferenceArgs>) {
        this.domains = Output.all(values.asList())
    }

    /**
     * @param values List of domains.
     */
    @JvmName("xatkcefwhwldkiaa")
    public suspend fun domains(values: List<Output<ActivatedResourceReferenceArgs>>) {
        this.domains = Output.all(values)
    }

    /**
     * @param value List of paths
     */
    @JvmName("qxdjkbnlogdydyek")
    public suspend fun patternsToMatch(`value`: Output<List<String>>) {
        this.patternsToMatch = value
    }

    @JvmName("vkdcmpwmkkfkutbo")
    public suspend fun patternsToMatch(vararg values: Output<String>) {
        this.patternsToMatch = Output.all(values.asList())
    }

    /**
     * @param values List of paths
     */
    @JvmName("bqwwjuobcineinam")
    public suspend fun patternsToMatch(values: List<Output<String>>) {
        this.patternsToMatch = Output.all(values)
    }

    /**
     * @param value List of domains.
     */
    @JvmName("fymuhfmynqprsfme")
    public suspend fun domains(`value`: List<ActivatedResourceReferenceArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.domains = mapped
    }

    /**
     * @param argument List of domains.
     */
    @JvmName("khdmitjiomoeshxp")
    public suspend
    fun domains(argument: List<suspend ActivatedResourceReferenceArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ActivatedResourceReferenceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.domains = mapped
    }

    /**
     * @param argument List of domains.
     */
    @JvmName("cnswhtetyvdoiune")
    public suspend fun domains(
        vararg
        argument: suspend ActivatedResourceReferenceArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ActivatedResourceReferenceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.domains = mapped
    }

    /**
     * @param argument List of domains.
     */
    @JvmName("vmrrpdccimliaogg")
    public suspend fun domains(argument: suspend ActivatedResourceReferenceArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            ActivatedResourceReferenceArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.domains = mapped
    }

    /**
     * @param values List of domains.
     */
    @JvmName("bnyqjmnciomcorcg")
    public suspend fun domains(vararg values: ActivatedResourceReferenceArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.domains = mapped
    }

    /**
     * @param value List of paths
     */
    @JvmName("ybmmlsijgthglwtr")
    public suspend fun patternsToMatch(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.patternsToMatch = mapped
    }

    /**
     * @param values List of paths
     */
    @JvmName("axnrvydplebjciwv")
    public suspend fun patternsToMatch(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.patternsToMatch = mapped
    }

    internal fun build(): SecurityPolicyWebApplicationFirewallAssociationArgs =
        SecurityPolicyWebApplicationFirewallAssociationArgs(
            domains = domains,
            patternsToMatch = patternsToMatch,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/cdn/kotlin/inputs/SecurityPolicyWebApplicationFirewallAssociationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.cdn.kotlin.inputs

import com.pulumi.azurenative.cdn.inputs.SecurityPolicyWebApplicationFirewallAssociationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * settings for security policy patterns to match
 * @property domains List of domains.
 * @property patternsToMatch List of paths
 */
public data class SecurityPolicyWebApplicationFirewallAssociationArgs(
    public val domains: Output<List<ActivatedResourceReferenceArgs>>? = null,
    public val patternsToMatch: Output<List<String>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.cdn.inputs.SecurityPolicyWebApplicationFirewallAssociationArgs> {
    override fun toJava():
        com.pulumi.azurenative.cdn.inputs.SecurityPolicyWebApplicationFirewallAssociationArgs =
        com.pulumi.azurenative.cdn.inputs.SecurityPolicyWebApplicationFirewallAssociationArgs.builder()
            .domains(
                domains?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .patternsToMatch(patternsToMatch?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [SecurityPolicyWebApplicationFirewallAssociationArgs].
 */
@PulumiTagMarker
public class SecurityPolicyWebApplicationFirewallAssociationArgsBuilder internal constructor() {
    private var domains: Output<List<ActivatedResourceReferenceArgs>>? = null

    private var patternsToMatch: Output<List<String>>? = null

    /**
     * @param value List of domains.
     */
    @JvmName("dkxjglgtoqvnpqxc")
    public suspend fun domains(`value`: Output<List<ActivatedResourceReferenceArgs>>) {
        this.domains = value
    }

    @JvmName("mhcabxcgvbapilai")
    public suspend fun domains(vararg values: Output<ActivatedResourceReferenceArgs>) {
        this.domains = Output.all(values.asList())
    }

    /**
     * @param values List of domains.
     */
    @JvmName("kkkysgodffqjcudu")
    public suspend fun domains(values: List<Output<ActivatedResourceReferenceArgs>>) {
        this.domains = Output.all(values)
    }

    /**
     * @param value List of paths
     */
    @JvmName("ssqqglxbdnfmbgmn")
    public suspend fun patternsToMatch(`value`: Output<List<String>>) {
        this.patternsToMatch = value
    }

    @JvmName("mjnovqlkkxtidpak")
    public suspend fun patternsToMatch(vararg values: Output<String>) {
        this.patternsToMatch = Output.all(values.asList())
    }

    /**
     * @param values List of paths
     */
    @JvmName("gkfqmvplenvjoaee")
    public suspend fun patternsToMatch(values: List<Output<String>>) {
        this.patternsToMatch = Output.all(values)
    }

    /**
     * @param value List of domains.
     */
    @JvmName("pbkgwkguyebieplm")
    public suspend fun domains(`value`: List<ActivatedResourceReferenceArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.domains = mapped
    }

    /**
     * @param argument List of domains.
     */
    @JvmName("aciqxuhbuaycxbkd")
    public suspend
    fun domains(argument: List<suspend ActivatedResourceReferenceArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ActivatedResourceReferenceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.domains = mapped
    }

    /**
     * @param argument List of domains.
     */
    @JvmName("ptaaegtefgjwppvm")
    public suspend fun domains(
        vararg
        argument: suspend ActivatedResourceReferenceArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ActivatedResourceReferenceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.domains = mapped
    }

    /**
     * @param argument List of domains.
     */
    @JvmName("qiuhmujbjwnexmdp")
    public suspend fun domains(argument: suspend ActivatedResourceReferenceArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            ActivatedResourceReferenceArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.domains = mapped
    }

    /**
     * @param values List of domains.
     */
    @JvmName("wshwqhlehkmssbpc")
    public suspend fun domains(vararg values: ActivatedResourceReferenceArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.domains = mapped
    }

    /**
     * @param value List of paths
     */
    @JvmName("trrjhgkssrutorsk")
    public suspend fun patternsToMatch(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.patternsToMatch = mapped
    }

    /**
     * @param values List of paths
     */
    @JvmName("tnwsicnlkhaklurw")
    public suspend fun patternsToMatch(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.patternsToMatch = mapped
    }

    internal fun build(): SecurityPolicyWebApplicationFirewallAssociationArgs =
        SecurityPolicyWebApplicationFirewallAssociationArgs(
            domains = domains,
            patternsToMatch = patternsToMatch,
        )
}
